/*******************************************************************************
 * Copyright  2000, 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.sqlbuilder.views;

import org.eclipse.datatools.modelbase.sql.query.QueryStatement;
import org.eclipse.datatools.sqltools.sqlbuilder.Messages;
import org.eclipse.datatools.sqltools.sqlbuilder.model.SQLDomainModel;
import org.eclipse.datatools.sqltools.sqlbuilder.util.ViewUtility;
import org.eclipse.jface.viewers.ContentViewer;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Text;


/**
 * Create the viewer for the statement name
 */
public class StatementNameViewer extends ContentViewer implements Listener {

    protected Text nameField;
    protected QueryStatement currentStatement;
    protected SQLDomainModel domainModel;
    protected Composite mainUIComponent;

    public final static Object P_STATEMENT_NAME = "org.eclipse.datatools.sqltools.sqlbuilder.view.StatementName";

    public StatementNameViewer(SQLDomainModel sqlDomainModel) {
        domainModel = sqlDomainModel;
        currentStatement = sqlDomainModel.getSQLStatement();
    }

    public void setInput(Object input) {
        nameField.removeListener(SWT.Modify, this);

        if (input instanceof QueryStatement) {
            currentStatement = (QueryStatement) input;
            String name = currentStatement.getName();
            if (name == null) {
            	// do not set the text because it can not be null
                nameField.addListener(SWT.Modify, this);
                return;
            }
            nameField.setText(currentStatement.getName());
        }

        nameField.addListener(SWT.Modify, this);
        super.setInput(input);
    }

    /**
     * Framework override
     */
    public Control getControl() {
        return mainUIComponent;
    }

    public Control createControl(Composite parent) {
        // Create the main UI container
        mainUIComponent = new Composite(parent, SWT.NULL);

        GridLayout layout = new GridLayout();

        layout.marginHeight = 5;
        layout.marginWidth = 5;
        layout.horizontalSpacing = 5;
        layout.verticalSpacing = 5;

        layout.numColumns = 2;
        mainUIComponent.setLayout(layout);

        mainUIComponent.setLayoutData(ViewUtility.createHorizontalFill());

        ViewUtility.createLabel(mainUIComponent, Messages._UI_LABEL_STATEMENT);
        nameField = new Text(mainUIComponent, SWT.SINGLE | SWT.BORDER | SWT.READ_ONLY);

        GridData data = new GridData();
        data.horizontalAlignment = GridData.FILL;
        data.grabExcessHorizontalSpace = true;
        data.widthHint = 20;
        nameField.setLayoutData(data);
        hookControl(mainUIComponent);
        return mainUIComponent;
    }

    public void handleEvent(Event event) {
        currentStatement.setName(nameField.getText());
    }

    public void refresh() {
    }

    public ISelection getSelection() {
        return null;
    }

    public void setSelection(ISelection selection, boolean reveal) {
    }

}
